==> ejc-equipment-impl-3.0.0-20221031.081435-393-sources.jar: com/ejianc/business/equipment/service/IPurchaseSettlementService.java <==
package com.ejianc.business.equipment.service;

import com.ejianc.business.equipment.bean.PurchaseSettlementEntity;
import com.ejianc.business.equipment.vo.PurchaseSettlementRecordVO;
import com.ejianc.business.equipment.vo.PurchaseSettlementVO;
import com.ejianc.business.equipment.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 设备合同结算表 服务类
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public interface IPurchaseSettlementService extends IBaseService<PurchaseSettlementEntity> {

    /**
     * 保存或修改信息
     *
     * @param PurchaseSettlementVo
     * @return
     */
    CommonResponse<PurchaseSettlementVO> saveOrUpdate(PurchaseSettlementVO PurchaseSettlementVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    PurchaseSettlementVO queryDetail(Long id);

    PurchaseSettlementVO queryDetails(Long id);

    void costPush(PurchaseSettlementEntity settlementEntity);

    PurchaseSettlementRecordVO querySettlementRecord(Long id);
    /**
     * 删除信息
     *
     * @param vos
     */
    void deletePurchaseSettlement(List<PurchaseSettlementVO> vos);

    CommonResponse<PurchaseSettlementVO> pushCost(PurchaseSettlementVO purchaseSettlementVO);

    //成改制考
    void pullCost(Long id);

    ParamsCheckVO checkParams(Integer purchaseType, BigDecimal sumPayMny, BigDecimal payMny, BigDecimal contractMny, Long projectId);
}

==> ejc-equipment-impl-3.0.0-20251103.014736-497-sources.jar: com/ejianc/business/equipment/service/IPurchaseSettlementService.java <==
package com.ejianc.business.equipment.service;

import com.ejianc.business.equipment.bean.PurchaseSettlementEntity;
import com.ejianc.business.equipment.vo.PurchaseSettlementRecordVO;
import com.ejianc.business.equipment.vo.PurchaseSettlementVO;
import com.ejianc.business.equipment.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 设备合同结算表 服务类
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public interface IPurchaseSettlementService extends IBaseService<PurchaseSettlementEntity> {

    /**
     * 保存或修改信息
     *
     * @param PurchaseSettlementVo
     * @return
     */
    CommonResponse<PurchaseSettlementVO> saveOrUpdate(PurchaseSettlementVO PurchaseSettlementVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    PurchaseSettlementVO queryDetail(Long id);

    PurchaseSettlementVO queryDetails(Long id);

    void costPush(PurchaseSettlementEntity settlementEntity);

    PurchaseSettlementRecordVO querySettlementRecord(Long id);
    /**
     * 删除信息
     *
     * @param vos
     */
    void deletePurchaseSettlement(List<PurchaseSettlementVO> vos);

    CommonResponse<PurchaseSettlementVO> pushCost(PurchaseSettlementVO purchaseSettlementVO);

    //成改制考
    void pullCost(Long id);

    ParamsCheckVO checkParams(Integer purchaseType, BigDecimal sumPayMny, BigDecimal payMny, BigDecimal contractMny, Long projectId, Long orgId);
}
